@@ -4,7 +4,12 @@ use warnings;
 
 use base qw(Pod::Abstract::Filter);
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
+
+=head1 NAME
+
+Pod::Abstract::Filter::unoverlay - paf command to remove "overlay" blocks
+from a Pod document, as created by the paf overlay command.
 
 =begin :overlay
 
